@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-08-31'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,7 +66,6 @@ sub _add_prereqs_from_func_meta {
     }
 
     {
-        last unless $cli_info;
         my $args = $meta->{args};
         last unless $args;
         for my $arg_name (keys %$args) {
@@ -76,20 +75,20 @@ sub _add_prereqs_from_func_meta {
             # from x.schema.{entity,element_entity} & x.completion (cli scripts
             # only)
             $e = $arg_spec->{'x.schema.entity'};
-            if ($e) {
+            if ($e && $cli_info) {
                 $self->_add_prereq("Perinci::Sub::ArgEntity::$e"=>0);
             }
             $e = $arg_spec->{'x.schema.element_entity'};
-            if ($e) {
+            if ($e && $cli_info) {
                 $self->_add_prereq("Perinci::Sub::ArgEntity::$e"=>0);
             }
             $e = $arg_spec->{'x.completion'};
-            if ($e) {
+            if ($e && $cli_info) {
                 die "x.completion must be an array" unless ref($e) eq 'ARRAY';
                 $self->_add_prereq("Perinci::Sub::XCompletion::$e->[0]"=>0);
             }
             $e = $arg_spec->{'x.element_completion'};
-            if ($e) {
+            if ($e && $cli_info) {
                 die "x.element_completion must be an array" unless ref($e) eq 'ARRAY';
                 $self->_add_prereq("Perinci::Sub::XCompletion::$e->[0]"=>0);
             }
@@ -103,7 +102,7 @@ sub _add_prereqs_from_func_meta {
                 };
                 my $cd = $plc->compile(schema => $sch);
                 for my $mod (@{ $cd->{modules} }) {
-                    if ($cli_info->[3]{'func.is_inline'}) {
+                    if ($cli_info && $cli_info->[3]{'func.is_inline'}) {
                         next unless $mod->{phase} eq 'runtime';
                     } else {
                         next unless $mod->{phase} eq 'compile';
@@ -142,6 +141,7 @@ sub munge_file {
         $self->log_debug(["Found module with non-empty %%SPEC: %s (%s)", $file->name, $pkg])
             if keys %$spec;
         for my $func (grep {/\A\w+\z/} sort keys %$spec) {
+            $self->log_debug(["Found function from \%%SPEC: %s\::%s", $pkg, $func]);
             $self->_add_prereqs_from_func_meta($spec->{$func}, 0);
         }
     } else {
@@ -173,17 +173,24 @@ sub munge_file {
 
             # add prereq to package, unless it's from our own dist
             my $pkg = $1; $pkg =~ s!/!::!g;
-            next if $pkg eq 'main';
 
-            $self->_add_prereq($pkg => 0) unless $self->{_packages}{$pkg};
+            my @metas;
+            if ($pkg eq 'main') {
+                my $fmetas = $res->[3]{'func.meta'};
+                next unless $fmetas;
+                push @metas, values %$fmetas;
+            } else {
+                $self->_add_prereq($pkg => 0) unless $self->{_packages}{$pkg};
+                $self->log_debug(["Performing Riap request: meta => %s", $url]);
+                my $res = $pa->request(meta => $url);
+                $self->log_fatal(["Can't meta %s: %s-%s", $url, $res->[0], $res->[1]])
+                    unless $res->[0] == 200;
+                push @metas, $res->[2];
+            }
 
-            # get its metadata
-            $self->log_debug(["Performing Riap request: meta => %s", $url]);
-            my $res = $pa->request(meta => $url);
-            $self->log_fatal(["Can't meta %s: %s-%s", $url, $res->[0], $res->[1]])
-                unless $res->[0] == 200;
-            my $meta = $res->[2];
-            $self->_add_prereqs_from_func_meta($meta, $cli_info);
+            for my $meta (@metas) {
+                $self->_add_prereqs_from_func_meta($meta, $cli_info);
+            }
         }
     }
 }
@@ -204,7 +211,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.10 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-07-22.
+This document describes version 0.11 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-08-31.
 
 =head1 SYNOPSIS
 
